# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/grid_description.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'proto/grid_description.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cproto/grid_description.proto\x12\x16proto.grid_description\"\xc3\x01\n\x0fGridDescription\x12>\n\x04mode\x18\x01 \x01(\x0e\x32\x30.proto.grid_description.GridDescription.GridMode\x12\x12\n\nhor_angles\x18\x02 \x03(\x01\x12\x12\n\nver_angles\x18\x03 \x03(\x01\x12\x11\n\tmax_range\x18\x04 \x01(\x01\"5\n\x08GridMode\x12\n\n\x06kFixed\x10\x00\x12\x1d\n\x15OBSELETE_kAlternating\x10\x01\x1a\x02\x08\x01\x42\x02H\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.grid_description_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\003'
  _globals['_GRIDDESCRIPTION_GRIDMODE'].values_by_name["OBSELETE_kAlternating"]._loaded_options = None
  _globals['_GRIDDESCRIPTION_GRIDMODE'].values_by_name["OBSELETE_kAlternating"]._serialized_options = b'\010\001'
  _globals['_GRIDDESCRIPTION']._serialized_start=57
  _globals['_GRIDDESCRIPTION']._serialized_end=252
  _globals['_GRIDDESCRIPTION_GRIDMODE']._serialized_start=199
  _globals['_GRIDDESCRIPTION_GRIDMODE']._serialized_end=252
# @@protoc_insertion_point(module_scope)
