from proto import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NmeaData(_message.Message):
    __slots__ = ("time", "playback_time", "sentence")
    TIME_FIELD_NUMBER: _ClassVar[int]
    PLAYBACK_TIME_FIELD_NUMBER: _ClassVar[int]
    SENTENCE_FIELD_NUMBER: _ClassVar[int]
    time: _time_pb2.Time
    playback_time: _time_pb2.Time
    sentence: str
    def __init__(self, time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., playback_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., sentence: _Optional[str] = ...) -> None: ...
