# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/nmea.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'proto/nmea.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto import time_pb2 as proto_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10proto/nmea.proto\x12\nproto.nmea\x1a\x10proto/time.proto\"e\n\x08NmeaData\x12\x1e\n\x04time\x18\x01 \x01(\x0b\x32\x10.proto.time.Time\x12\'\n\rplayback_time\x18\x03 \x01(\x0b\x32\x10.proto.time.Time\x12\x10\n\x08sentence\x18\x02 \x01(\tB\x02H\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.nmea_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\003'
  _globals['_NMEADATA']._serialized_start=50
  _globals['_NMEADATA']._serialized_end=151
# @@protoc_insertion_point(module_scope)
