# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/nav_info.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'proto/nav_info.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto import nmea_pb2 as proto_dot_nmea__pb2
from proto import time_pb2 as proto_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14proto/nav_info.proto\x12\x0eproto.nav_info\x1a\x10proto/nmea.proto\x1a\x10proto/time.proto\":\n\x05\x44\x65pth\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x01\x12\"\n\x04nmea\x18\x02 \x01(\x0b\x32\x14.proto.nmea.NmeaData\"\xbe\x01\n\x07Heading\x12\x0f\n\x07heading\x18\x01 \x01(\x01\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.proto.nav_info.Heading.Type\x12\"\n\x04nmea\x18\x03 \x01(\x0b\x32\x14.proto.nmea.NmeaData\"R\n\x04Type\x12\x14\n\x10OBSOLETE_kSensor\x10\x00\x12\x16\n\x12OBSOLETE_kMagnetic\x10\x01\x12\t\n\x05kTrue\x10\x02\x12\x11\n\rkManufactured\x10\x03\"H\n\x08Position\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lon\x18\x02 \x01(\x01\x12\"\n\x04nmea\x18\x07 \x01(\x0b\x32\x14.proto.nmea.NmeaData\":\n\x05Speed\x12\r\n\x05speed\x18\x01 \x01(\x01\x12\"\n\x04nmea\x18\x02 \x01(\x0b\x32\x14.proto.nmea.NmeaData\"h\n\tDualSpeed\x12\x1a\n\x12ground_transversal\x18\x01 \x01(\x02\x12\x1b\n\x13ground_longitudinal\x18\x02 \x01(\x02\x12\"\n\x04nmea\x18\x03 \x01(\x0b\x32\x14.proto.nmea.NmeaData\"=\n\nRateOfTurn\x12\x0b\n\x03rot\x18\x01 \x01(\x02\x12\"\n\x04nmea\x18\x02 \x01(\x0b\x32\x14.proto.nmea.NmeaData\"L\n\x10\x43ourseOverGround\x12\x14\n\x0ctrue_heading\x18\x01 \x01(\x02\x12\"\n\x04nmea\x18\x02 \x01(\x0b\x32\x14.proto.nmea.NmeaData\")\n\x03\x41IS\x12\"\n\x04nmea\x18\x01 \x01(\x0b\x32\x14.proto.nmea.NmeaData\"*\n\x04\x41RPA\x12\"\n\x04nmea\x18\x01 \x01(\x0b\x32\x14.proto.nmea.NmeaData\")\n\x07UTCTime\x12\x1e\n\x04time\x18\x01 \x01(\x0b\x32\x10.proto.time.Time\"+\n\tLocalTime\x12\x1e\n\x04time\x18\x01 \x01(\x0b\x32\x10.proto.time.Time\"\xd7\x01\n\rFilteredState\x12\x1e\n\x04time\x18\x07 \x01(\x0b\x32\x10.proto.time.Time\x12\x16\n\x0e\x66ilter_enabled\x18\x08 \x01(\x08\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lon\x18\x02 \x01(\x01\x12\x1a\n\x12latlon_is_filtered\x18\t \x01(\x08\x12\x0f\n\x07heading\x18\x04 \x01(\x01\x12\x1b\n\x13heading_is_filtered\x18\n \x01(\x08\x12\r\n\x05speed\x18\x03 \x01(\x01\x12\x0e\n\x06\x63ourse\x18\x05 \x01(\x01\x12\x0b\n\x03rot\x18\x06 \x01(\x01\x42\x02H\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.nav_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\003'
  _globals['_DEPTH']._serialized_start=76
  _globals['_DEPTH']._serialized_end=134
  _globals['_HEADING']._serialized_start=137
  _globals['_HEADING']._serialized_end=327
  _globals['_HEADING_TYPE']._serialized_start=245
  _globals['_HEADING_TYPE']._serialized_end=327
  _globals['_POSITION']._serialized_start=329
  _globals['_POSITION']._serialized_end=401
  _globals['_SPEED']._serialized_start=403
  _globals['_SPEED']._serialized_end=461
  _globals['_DUALSPEED']._serialized_start=463
  _globals['_DUALSPEED']._serialized_end=567
  _globals['_RATEOFTURN']._serialized_start=569
  _globals['_RATEOFTURN']._serialized_end=630
  _globals['_COURSEOVERGROUND']._serialized_start=632
  _globals['_COURSEOVERGROUND']._serialized_end=708
  _globals['_AIS']._serialized_start=710
  _globals['_AIS']._serialized_end=751
  _globals['_ARPA']._serialized_start=753
  _globals['_ARPA']._serialized_end=795
  _globals['_UTCTIME']._serialized_start=797
  _globals['_UTCTIME']._serialized_end=838
  _globals['_LOCALTIME']._serialized_start=840
  _globals['_LOCALTIME']._serialized_end=883
  _globals['_FILTEREDSTATE']._serialized_start=886
  _globals['_FILTEREDSTATE']._serialized_end=1101
# @@protoc_insertion_point(module_scope)
