# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: proto/array.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'proto/array.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11proto/array.proto\x12\x0bproto.array\"\xc4\x02\n\tArrayData\x12\x0c\n\x04\x64ims\x18\x01 \x03(\x05\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x1b.proto.array.ArrayData.Type\x12+\n\x05order\x18\x03 \x01(\x0e\x32\x1c.proto.array.ArrayData.Order\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"\x98\x01\n\x04Type\x12\x08\n\x04\x42YTE\x10\x00\x12\t\n\x05INT16\x10\x01\x12\n\n\x06UINT16\x10\x02\x12\t\n\x05INT32\x10\x03\x12\n\n\x06UINT32\x10\x04\x12\t\n\x05INT64\x10\x05\x12\n\n\x06UINT64\x10\x06\x12\x0b\n\x07\x46LOAT32\x10\x07\x12\x0b\n\x07\x46LOAT64\x10\x08\x12\r\n\tCOMPLEX64\x10\t\x12\x0e\n\nCOMPLEX128\x10\n\x12\x08\n\x04\x42OOL\x10\x0b\"(\n\x05Order\x12\r\n\tROW_MAJOR\x10\x00\x12\x10\n\x0c\x43OLUMN_MAJOR\x10\x01\x42\x02H\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'proto.array_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'H\003'
  _globals['_ARRAYDATA']._serialized_start=35
  _globals['_ARRAYDATA']._serialized_end=359
  _globals['_ARRAYDATA_TYPE']._serialized_start=165
  _globals['_ARRAYDATA_TYPE']._serialized_end=317
  _globals['_ARRAYDATA_ORDER']._serialized_start=319
  _globals['_ARRAYDATA_ORDER']._serialized_end=359
# @@protoc_insertion_point(module_scope)
